romp_bootstrap

Function romp_bootstrap 

pub fn romp_bootstrap() -> BootstrapFuture
Initialises the romp server, this method should be called once bespoke filters have been registered with the routers.