StompParser

Struct StompParser 

pub struct StompParser {
    pub message: StompMessage,
    /* private fields */
}
A push parser, externally a buffer is being filled with the STOMP message and headers as it arrive we process the data as it comes off the stream and save state between chunks of data arriving.

Fields

message: StompMessage

Implementations

Source

impl StompParser

pub fn new(session_id: usize) -> StompParser

pub fn take_message(&mut self, owner: Ownership) -> StompMessage

take ownership of the parsed message

pub fn reset(&mut self)

reset wiping the message

pub fn bytes_read(&self) -> usize

pub fn push( &mut self, buffer: &[u8], pos: usize, chunk: &[u8], ) -> Result<ParserState, ParserState>

Required a complete rewrite from xtomp because rust does not have for loops or p++ and can not index arrays easily

buffer the full buffer we are loading pos position in the outer buffer (not the chunk) chunk slice of input buffer we are reading