pub fn insert_stomp(
closure: fn(_: &mut Context, message: &mut StompMessage) -> Result<bool, FilterError>,
)Expand description
Insert a bespoke filter as a closure into the filter chain
Panics
if called after bootstrapping the server.
pub fn insert_stomp(
closure: fn(_: &mut Context, message: &mut StompMessage) -> Result<bool, FilterError>,
)Insert a bespoke filter as a closure into the filter chain
if called after bootstrapping the server.